==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/DataConsentReview.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import org.hibernate.Session;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.utils.AbstractBeanRelationsAttributes;
import pt.digitalis.dif.model.utils.IBeanAttributesDataSet;

/**
 * DataConsentReview
* Generated on ORM Generator
* DIF build process for the Model layer
*
*/
@SuppressWarnings("serial")
public class DataConsentReview extends AbstractBeanRelationsAttributes implements java.io.Serializable, IBeanAttributesDataSet<DataConsentReview> {

    /** DataConsentReview attributes enumeration */
    public static class Fields
    {
        /** id column */
        public static final String ID ="id";
        /** lastReviewDate column */
        public static final String LASTREVIEWDATE ="lastReviewDate";

        /**
         * List of existing fields
         *
         * @return list of field names
         */
        public static List<String> values()
        {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("lastReviewDate");

            return list;
        }
    }

    /** Field attributes */
    public static DataConsentReviewFieldAttributes FieldAttributes=new DataConsentReviewFieldAttributes();

    /**
    * @return the field attributes definitions
    */
    @Override public DataConsentReviewFieldAttributes getDefinitions()
    {
        return FieldAttributes;
    }

    /**
     * The Class Relations.
     */
    public class Relations extends AbstractBeanRelationsAttributes.AbstractRelations
    {

        /**
        * Instantiates a new relations.
        *
        * @param currentPath the current path
        */
        public Relations(String currentPath)
        {
            super(currentPath);
        }
        /**
         * dataConsent relation.
         *
         * @return the dataConsent bean relations attributes.
         */
        public DataConsent.Relations dataConsent()
        {
            DataConsent c = new DataConsent();
            return c.new Relations(this.buildPath("dataConsent"));
        }

        /**
         * dataConsentUser relation.
         *
         * @return the dataConsentUser bean relations attributes.
         */
        public DataConsentUser.Relations dataConsentUser()
        {
            DataConsentUser c = new DataConsentUser();
            return c.new Relations(this.buildPath("dataConsentUser"));
        }

        /**
         * the ID path.
         *
         * @return the path
         */
        public String ID()
        {
            return buildPath(Fields.ID);
        }
        /**
         * the LASTREVIEWDATE path.
         *
         * @return the path
         */
        public String LASTREVIEWDATE()
        {
            return buildPath(Fields.LASTREVIEWDATE);
        }
    }

    /** The dummy obj. */
    private static DataConsentReview dummyObj=new DataConsentReview();

    /**
     * Get DataConsentReview Relations .
     *
     * @return the relations
     */
    public static Relations FK()
    {
        return dummyObj.new Relations(null);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public IDataSet<DataConsentReview> getDataSet()
    {
        return new HibernateDataSet<DataConsentReview>(DataConsentReview.class, HibernateUtil.getSessionFactory("DIFRepository"),
            DataConsentReview.getPKFieldListAsString(), DataConsentReview.FieldAttributes);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public static IDataSet<DataConsentReview> getDataSetInstance()
    {
        return new DataConsentReview().getDataSet();
    }

    /**
    * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
    */
    @Override protected Object getAttributeNoGraphNavigation(String attributeName)
    {
        if("id".equalsIgnoreCase(attributeName))
            return id;
        if("dataConsent".equalsIgnoreCase(attributeName))
            return dataConsent;
        if("dataConsentUser".equalsIgnoreCase(attributeName))
            return dataConsentUser;
        if("lastReviewDate".equalsIgnoreCase(attributeName))
            return lastReviewDate;

        return null;
    }

    /**
    * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
    */
    public void setAttribute(String attributeName,Object attributeValue)
    {
        if("id".equalsIgnoreCase(attributeName))
            id =(Long)attributeValue;
        if("dataConsent".equalsIgnoreCase(attributeName))
            dataConsent =(DataConsent)attributeValue;
        if("dataConsentUser".equalsIgnoreCase(attributeName))
            dataConsentUser =(DataConsentUser)attributeValue;
        if("lastReviewDate".equalsIgnoreCase(attributeName))
            lastReviewDate =(Timestamp)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** dataConsent private attribute */
    private DataConsent dataConsent;

    /** dataConsentUser private attribute */
    private DataConsentUser dataConsentUser;

    /** lastReviewDate private attribute */
    private Timestamp lastReviewDate;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else {
            return value.toString().trim();
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public DataConsentReview() {
    }

	/** 
	 * minimal constructor
	 *
     * @param dataConsent the dataConsent
     * @param lastReviewDate the lastReviewDate
    }
	 */
    public DataConsentReview(DataConsent dataConsent, Timestamp lastReviewDate) {
        this.dataConsent = dataConsent;
        this.lastReviewDate = lastReviewDate;
    }

    /**
     * full constructor
	 *
     * @param dataConsent the dataConsent
     * @param dataConsentUser the dataConsentUser
     * @param lastReviewDate the lastReviewDate
     */
    public DataConsentReview(DataConsent dataConsent, DataConsentUser dataConsentUser, Timestamp lastReviewDate) {
        this.dataConsent = dataConsent;
        this.dataConsentUser = dataConsentUser;
        this.lastReviewDate = lastReviewDate;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id the id
     *
     * @return DataConsentReview modified instance
     */
    public DataConsentReview setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * dataConsent getter method
     *
     * @return dataConsent method
     */
    public DataConsent getDataConsent() {
        return this.dataConsent;
    }
    
    /**       
     * dataConsent setter method
     *
     * @param dataConsent the dataConsent
     *
     * @return DataConsentReview modified instance
     */
    public DataConsentReview setDataConsent(DataConsent dataConsent) {
        this.dataConsent = dataConsent;
        
        return this;
    }
    /**       
     * dataConsentUser getter method
     *
     * @return dataConsentUser method
     */
    public DataConsentUser getDataConsentUser() {
        return this.dataConsentUser;
    }
    
    /**       
     * dataConsentUser setter method
     *
     * @param dataConsentUser the dataConsentUser
     *
     * @return DataConsentReview modified instance
     */
    public DataConsentReview setDataConsentUser(DataConsentUser dataConsentUser) {
        this.dataConsentUser = dataConsentUser;
        
        return this;
    }
    /**       
     * lastReviewDate getter method
     *
     * @return lastReviewDate method
     */
    public Timestamp getLastReviewDate() {
        return this.lastReviewDate;
    }
    
    /**       
     * lastReviewDate setter method
     *
     * @param lastReviewDate the lastReviewDate
     *
     * @return DataConsentReview modified instance
     */
    public DataConsentReview setLastReviewDate(Timestamp lastReviewDate) {
        this.lastReviewDate = lastReviewDate;
        
        return this;
    }

    /**
     * Creates a String representation of the DataConsentReview object
     *
     * @return the compiled String
     */
    @Override
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("lastReviewDate").append("='").append(getLastReviewDate()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the DataConsentReview object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(DataConsentReview other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("lastReviewDate".equalsIgnoreCase(attributeName))
            this.lastReviewDate = Timestamp.valueOf(attributeValue);

    }


    /**
     * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
     *
     * @param session the session
     * @param id      the id
     *
     * @return the proxy
     */
    public static DataConsentReview getProxy(Session session, Long id)
    {
        return(DataConsentReview)session.load(DataConsentReview.class,id);
    }

    /**
    * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
    *
    * @param id      the id
    *
    * @return the proxy
    */
    public static DataConsentReview getProxy(Long id)
    {
        Session session = HibernateUtil.getSessionFactory("DIFRepository").getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        DataConsentReview result = (DataConsentReview)session.load(DataConsentReview.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }


    /**
     * Instanciates an Hibernate data object
     *
     * @param session the session
     * @param id      the id
     *
     * @return the instance
     */
    public static DataConsentReview getInstance(Session session, Long id)
    {
        return(DataConsentReview)session.get(DataConsentReview.class,id);
    }

    /**
    * Instanciates an Hibernate data object
    *
    * @param id      the id
    *
    * @return the instance
    */
    public static DataConsentReview getInstance(Long id)
    {
        Session session = HibernateUtil.getSessionFactory("DIFRepository").getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        DataConsentReview result = (DataConsentReview)session.get(DataConsentReview.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }

}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/DataConsentReview.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import org.hibernate.Session;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.utils.AbstractBeanRelationsAttributes;
import pt.digitalis.dif.model.utils.IBeanAttributesDataSet;

/**
 * DataConsentReview
* Generated on ORM Generator
* DIF build process for the Model layer
*
*/
@SuppressWarnings("serial")
public class DataConsentReview extends AbstractBeanRelationsAttributes implements java.io.Serializable, IBeanAttributesDataSet<DataConsentReview> {

    /**
    * Constant with the session factory ID
    */
    public static String SESSION_FACTORY_NAME = "DIFRepository";

    /** DataConsentReview attributes enumeration */
    public static class Fields
    {
        /** id column */
        public static final String ID ="id";
        /** lastReviewDate column */
        public static final String LASTREVIEWDATE ="lastReviewDate";

        /**
         * List of existing fields
         *
         * @return list of field names
         */
        public static List<String> values()
        {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("lastReviewDate");

            return list;
        }
    }

    /** Field attributes */
    public static DataConsentReviewFieldAttributes FieldAttributes=new DataConsentReviewFieldAttributes();

    /**
    * @return the field attributes definitions
    */
    @Override public DataConsentReviewFieldAttributes getDefinitions()
    {
        return FieldAttributes;
    }

    /**
     * The Class Relations.
     */
    public class Relations extends AbstractBeanRelationsAttributes.AbstractRelations
    {

        /**
        * Instantiates a new relations.
        *
        * @param currentPath the current path
        */
        public Relations(String currentPath)
        {
            super(currentPath);
        }
        /**
         * dataConsent relation.
         *
         * @return the dataConsent bean relations attributes.
         */
        public DataConsent.Relations dataConsent()
        {
            DataConsent c = new DataConsent();
            return c.new Relations(this.buildPath("dataConsent"));
        }

        /**
         * dataConsentUser relation.
         *
         * @return the dataConsentUser bean relations attributes.
         */
        public DataConsentUser.Relations dataConsentUser()
        {
            DataConsentUser c = new DataConsentUser();
            return c.new Relations(this.buildPath("dataConsentUser"));
        }

        /**
         * the ID path.
         *
         * @return the path
         */
        public String ID()
        {
            return buildPath(Fields.ID);
        }
        /**
         * the LASTREVIEWDATE path.
         *
         * @return the path
         */
        public String LASTREVIEWDATE()
        {
            return buildPath(Fields.LASTREVIEWDATE);
        }
    }

    /** The dummy obj. */
    private static DataConsentReview dummyObj=new DataConsentReview();

    /**
     * Get DataConsentReview Relations .
     *
     * @return the relations
     */
    public static Relations FK()
    {
        return dummyObj.new Relations(null);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public IDataSet<DataConsentReview> getDataSet()
    {
        return getDataSetInstance();
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public static IDataSet<DataConsentReview> getDataSetInstance()
    {
        return new HibernateDataSet<DataConsentReview>(DataConsentReview.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
            DataConsentReview.getPKFieldListAsString(), DataConsentReview.FieldAttributes);
    }

    /**
    * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
    */
    @Override protected Object getAttributeNoGraphNavigation(String attributeName)
    {
        if("id".equalsIgnoreCase(attributeName))
            return id;
        if("dataConsent".equalsIgnoreCase(attributeName))
            return dataConsent;
        if("dataConsentUser".equalsIgnoreCase(attributeName))
            return dataConsentUser;
        if("lastReviewDate".equalsIgnoreCase(attributeName))
            return lastReviewDate;

        return null;
    }

    /**
    * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
    */
    public void setAttribute(String attributeName,Object attributeValue)
    {
        if("id".equalsIgnoreCase(attributeName))
            id =(Long)attributeValue;
        if("dataConsent".equalsIgnoreCase(attributeName))
            dataConsent =(DataConsent)attributeValue;
        if("dataConsentUser".equalsIgnoreCase(attributeName))
            dataConsentUser =(DataConsentUser)attributeValue;
        if("lastReviewDate".equalsIgnoreCase(attributeName))
            lastReviewDate =(Timestamp)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** dataConsent private attribute */
    private DataConsent dataConsent;

    /** dataConsentUser private attribute */
    private DataConsentUser dataConsentUser;

    /** lastReviewDate private attribute */
    private Timestamp lastReviewDate;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * Gets description field.
     *
     * @return the description field
     */
    @Override
    public String getDescriptionField()
    {
        return FieldAttributes.getDescriptionField();
    }

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
    @Override
    public List<String> getPKFields()
    {
        return getPKFieldList();
    }

    /**
     * Is composite PK.
     *
     * @return the boolean
     */
    @Override
    public boolean isCompositePK()
    {
        return this.getPKFieldList().size() > 1;
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {
        if (attributeName.contains("."))
        {
            return this.getAttributeAsStringParseBeanPath(attributeName);
        }
        else
        {
            Object value = getAttribute(attributeName);

            if (value == null)
                return "";
            else {
                return value.toString().trim();
            }
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public DataConsentReview() {
    }

	/** 
	 * minimal constructor
	 *
     * @param dataConsent the dataConsent
     * @param lastReviewDate the lastReviewDate
    }
	 */
    public DataConsentReview(DataConsent dataConsent, Timestamp lastReviewDate) {
        this.dataConsent = dataConsent;
        this.lastReviewDate = lastReviewDate;
    }

    /**
     * full constructor
	 *
     * @param dataConsent the dataConsent
     * @param dataConsentUser the dataConsentUser
     * @param lastReviewDate the lastReviewDate
     */
    public DataConsentReview(DataConsent dataConsent, DataConsentUser dataConsentUser, Timestamp lastReviewDate) {
        this.dataConsent = dataConsent;
        this.dataConsentUser = dataConsentUser;
        this.lastReviewDate = lastReviewDate;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id the id
     *
     * @return DataConsentReview modified instance
     */
    public DataConsentReview setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * dataConsent getter method
     *
     * @return dataConsent method
     */
    public DataConsent getDataConsent() {
        return this.dataConsent;
    }
    
    /**       
     * dataConsent setter method
     *
     * @param dataConsent the dataConsent
     *
     * @return DataConsentReview modified instance
     */
    public DataConsentReview setDataConsent(DataConsent dataConsent) {
        this.dataConsent = dataConsent;
        
        return this;
    }
    /**       
     * dataConsentUser getter method
     *
     * @return dataConsentUser method
     */
    public DataConsentUser getDataConsentUser() {
        return this.dataConsentUser;
    }
    
    /**       
     * dataConsentUser setter method
     *
     * @param dataConsentUser the dataConsentUser
     *
     * @return DataConsentReview modified instance
     */
    public DataConsentReview setDataConsentUser(DataConsentUser dataConsentUser) {
        this.dataConsentUser = dataConsentUser;
        
        return this;
    }
    /**       
     * lastReviewDate getter method
     *
     * @return lastReviewDate method
     */
    public Timestamp getLastReviewDate() {
        return this.lastReviewDate;
    }
    
    /**       
     * lastReviewDate setter method
     *
     * @param lastReviewDate the lastReviewDate
     *
     * @return DataConsentReview modified instance
     */
    public DataConsentReview setLastReviewDate(Timestamp lastReviewDate) {
        this.lastReviewDate = lastReviewDate;
        
        return this;
    }

    /**
     * dataConsent id getter method
     *
     * @return dataConsent id method
     */
    public Long getDataConsentId() {
        if (this.dataConsent == null)
            return null;
        else
            return this.dataConsent.getId();
    }

    /**
     * DataConsent proxy setter method from id.
     *
     * @return DataConsentReview modified instance
     */
    public DataConsentReview setDataConsentProxyFromId(Long id)
    {
        if (id == null || id.equals(-1L))
            this.dataConsent = null;
        else
            this.dataConsent = DataConsent.getProxy(id);

        return this;
    }

    /**
     * DataConsent instance setter method from id.
     *
     * @return DataConsentReview modified instance
     */
    public DataConsentReview setDataConsentInstanceFromId(Long id)
    {
        if (id == null || id.equals(-1L))
            this.dataConsent = null;
        else
            this.dataConsent = DataConsent.getInstance(id);

        return this;
    }
    /**
     * dataConsentUser id getter method
     *
     * @return dataConsentUser id method
     */
    public Long getDataConsentUserId() {
        if (this.dataConsentUser == null)
            return null;
        else
            return this.dataConsentUser.getId();
    }

    /**
     * DataConsentUser proxy setter method from id.
     *
     * @return DataConsentReview modified instance
     */
    public DataConsentReview setDataConsentUserProxyFromId(Long id)
    {
        if (id == null || id.equals(-1L))
            this.dataConsentUser = null;
        else
            this.dataConsentUser = DataConsentUser.getProxy(id);

        return this;
    }

    /**
     * DataConsentUser instance setter method from id.
     *
     * @return DataConsentReview modified instance
     */
    public DataConsentReview setDataConsentUserInstanceFromId(Long id)
    {
        if (id == null || id.equals(-1L))
            this.dataConsentUser = null;
        else
            this.dataConsentUser = DataConsentUser.getInstance(id);

        return this;
    }

    /**
     * Creates a String representation of the DataConsentReview object
     *
     * @return the compiled String
     */
    @Override
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("lastReviewDate").append("='").append(getLastReviewDate()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the DataConsentReview object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(DataConsentReview other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("lastReviewDate".equalsIgnoreCase(attributeName))
            this.lastReviewDate = Timestamp.valueOf(attributeValue);

    }


    /**
     * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
     *
     * @param session the session
     * @param id      the id
     *
     * @return the proxy
     */
    public static DataConsentReview getProxy(Session session, Long id)
    {
        return(DataConsentReview)session.load(DataConsentReview.class,id);
    }

    /**
    * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
    *
    * @param id      the id
    *
    * @return the proxy
    */
    public static DataConsentReview getProxy(Long id)
    {
        Session session = HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME).getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        DataConsentReview result = (DataConsentReview)session.load(DataConsentReview.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }


    /**
     * Instanciates an Hibernate data object
     *
     * @param session the session
     * @param id      the id
     *
     * @return the instance
     */
    public static DataConsentReview getInstanceForSession(Session session, Long id)
    {
        return(DataConsentReview)session.get(DataConsentReview.class,id);
    }

    /**
    * Instanciates an Hibernate data object
    *
    * @param id      the id
    *
    * @return the instance
    */
    public static DataConsentReview getInstance(Long id)
    {
        Session session = HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME).getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        DataConsentReview result = (DataConsentReview)session.get(DataConsentReview.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }

}
